import { InsertRequest as InsertRequest$1, InsertResponse as InsertResponse$1, UpdateRequest as UpdateRequest$1, UpdateResponse as UpdateResponse$1, SaveRequest as SaveRequest$1, SaveResponse as SaveResponse$1, GetRequest as GetRequest$1, GetResponse as GetResponse$1, RemoveRequest as RemoveRequest$1, RemoveResponse as RemoveResponse$1, TruncateRequest as TruncateRequest$1, TruncateResponse as TruncateResponse$1, QueryRequest as QueryRequest$1, QueryResponse as QueryResponse$1, AggregationRequest as AggregationRequest$1, AggregationResponse as AggregationResponse$1, CountRequest as CountRequest$1, CountResponse as CountResponse$1, DistinctRequest as DistinctRequest$1, DistinctResponse as DistinctResponse$1, BulkInsertRequest as BulkInsertRequest$1, BulkInsertResponse as BulkInsertResponse$1, BulkSaveRequest as BulkSaveRequest$1, BulkSaveResponse as BulkSaveResponse$1, BulkUpdateRequest as BulkUpdateRequest$1, BulkUpdateResponse as BulkUpdateResponse$1, BulkRemoveRequest as BulkRemoveRequest$1, BulkRemoveResponse as BulkRemoveResponse$1, QueryReferencedRequest as QueryReferencedRequest$1, QueryReferencedResponse as QueryReferencedResponse$1, BulkInsertReferencesRequest as BulkInsertReferencesRequest$1, BulkInsertReferencesResponse as BulkInsertReferencesResponse$1, BulkReplaceReferencesRequest as BulkReplaceReferencesRequest$1, BulkReplaceReferencesResponse as BulkReplaceReferencesResponse$1, BulkRemoveReferencesRequest as BulkRemoveReferencesRequest$1, BulkRemoveReferencesResponse as BulkRemoveReferencesResponse$1, IsReferencedRequest as IsReferencedRequest$1, IsReferencedResponse as IsReferencedResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

interface InsertRequest {
    /** Item to insert. */
    item?: Record<string, any> | null;
    /** ID of the collection in which to insert the item. */
    dataCollectionId?: string;
}
interface InsertResponse {
    /** Inserted item. */
    item?: Record<string, any> | null;
}
interface UpdateRequest {
    /** Item to update. The existing item is replaced with this version. */
    item: Record<string, any> | null;
    /** ID of the collection containing the existing item. */
    dataCollectionId?: string;
}
interface UpdateResponse {
    /** Updated item */
    item?: Record<string, any> | null;
}
interface SaveRequest {
    /** Item to insert or update. */
    item?: Record<string, any> | null;
    /** ID of the collection in which to insert or update the item. */
    dataCollectionId?: string;
}
interface SaveResponse {
    /** Inserted or updated item. */
    item?: Record<string, any> | null;
}
interface GetRequest {
    /** ID of the item to retrieve. */
    itemId: string;
    /** ID of the collection from which to retrieve the item. */
    dataCollectionId?: string;
}
interface GetResponse {
    /** Retrieved item. */
    item?: Record<string, any> | null;
}
interface RemoveRequest {
    /** ID of the item to remove. */
    itemId: string;
    /** ID of the collection from which to remove the item. */
    dataCollectionId?: string;
}
interface RemoveResponse {
    /** Removed item. */
    item?: Record<string, any> | null;
}
interface TruncateRequest {
    /** ID of the collection to truncate. */
    dataCollectionId?: string;
}
interface TruncateResponse {
}
interface QueryRequest {
    /** Query preferences. For more details on using queries, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language). */
    dataQuery?: QueryV2;
    /**
     * Whether to omit the total count in the response.
     * When `true`, the `pagingMetadata` object in the response doesn't contain a `total` field.
     *
     * Default: `false`
     */
    omitTotalCount?: boolean;
    /**
     * Properties for which to include referenced items in the query's results.
     * Up to 50 referenced items can be included for each item that matches the query.
     * If more than 50 items are referenced, `partialIncludes` in the response is `true`.
     */
    includeReferencedItems?: string[];
    /** ID of the collection to query. */
    dataCollectionId?: string;
}
interface Sorting {
    /** Name of the field to sort by. */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /**
     * Number of items to load.
     * @max 1000
     */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     */
    sort?: Sorting[];
    /** Array of projected fields. A list of specific field names to return. */
    fields?: string[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface CursorPaging {
    /**
     * Number of items to load.
     * @max 1000
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * You can get the relevant cursor token
     * from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     */
    cursor?: string | null;
}
interface QueryResponse {
    /** Retrieved items. */
    items?: Record<string, any>[] | null;
    /**
     * *Deprecated.** Refer to 'pagingMetadata' instead. Total number of items satisfying the query.
     * @deprecated
     */
    totalCount?: number;
    /**
     * *Deprecated.** Refer to 'pagingMetadata' instead. Total number of items satisfying the query.
     * @deprecated
     */
    totalResults?: number;
    /** Whether referenced items are trimmed from the results. This occurs when there are more than 50 referenced items. */
    partialIncludes?: boolean;
    /** Paging information. */
    pagingMetadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /** Cursor pointing to next page in the list of results. */
    next?: string | null;
    /** Cursor pointing to previous page in the list of results. */
    prev?: string | null;
}
interface AggregationRequest {
    /** Paging preferences. */
    paging?: Paging;
    /** Filter applied to the collection's data prior to running the aggregation. See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language#getting-started_api-query-language_the-filter-section) for information on how to structure a filter object. */
    initialFilter?: Record<string, any> | null;
    /**
     * Object defining the steps of the aggregation to be This is an object defining aggregation itself.
     *
     * * Grouping rule is defined as _id field. It takes a form of:
     * {
     * "_id": "$field"
     * }
     *
     * If multiple fields are used for grouping, Group takes a form of:
     * {
     * "_id": {
     * "field1": "$field1"
     * "field2": "$field2"
     * }
     * }
     *
     * * Aggregation functions are defined as special field definitions.
     *
     * Average:
     * {
     * "_id": "$field"
     * "my_avg": {
     * "$avg": "$other_field"
     * }
     * }
     *
     * Max:
     * {
     * "_id": "$field"
     * "my_max": {
     * "$max": "$other_field"
     * }
     * }
     *
     * Min:
     * {
     * "_id": "$field"
     * "my_min": {
     * "$min": "$other_field"
     * }
     * }
     *
     * Sum:
     * {
     * "_id": "$field"
     * "my_sum": {
     * "$sum": "$other_field"
     * }
     * }
     */
    aggregation?: Record<string, any> | null;
    /** Filter applied to the processed data following the aggregation. See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language#getting-started_api-query-language_the-filter-section) for information on how to structure a filter object. */
    finalFilter?: Record<string, any> | null;
    /** Sorting preferences. */
    sort?: Sorting[];
    /** ID of the collection on which to run the aggregation. */
    dataCollectionId?: string;
}
interface AggregationResponse {
    /** Aggregation results. */
    items?: Record<string, any>[] | null;
    /** Paging information. */
    pagingMetadata?: PagingMetadataV2;
}
interface CountRequest {
    /** Filter preferences defining the query. For more information on how to structure a filter object, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language#getting-started_api-query-language_the-filter-section). */
    filter?: Record<string, any> | null;
    /** ID of the collection for which to count query results. */
    dataCollectionId?: string;
}
interface CountResponse {
    /** Count of items matching the query. */
    totalCount?: number;
    /**
     * *Deprecated.** Refer to `totalCount` instead.
     * @deprecated
     */
    totalResults?: number;
}
interface DistinctRequest {
    /** Query preferences. For more details on using queries, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language). */
    dataQuery?: QueryV2;
    /** Property name for which to return all distinct values. */
    propertyName: string;
    /** ID of the collection to query. */
    dataCollectionId?: string;
    /**
     * Whether to omit the total count in the response.
     * When `true`, the `pagingMetadata` object in the response doesn't contain a `total` field.
     *
     * Default: `false`
     */
    omitTotalCount?: boolean;
}
interface DistinctResponse {
    /** List of distinct values contained in the property specified in `propertyName`. */
    items?: any[];
    /** Paging information. */
    pagingMetadata?: PagingMetadataV2;
}
interface BulkInsertRequest {
    /** Items to insert. */
    items: Record<string, any>[] | null;
    /** ID of the collection in which to insert the items. */
    dataCollectionId?: string;
}
interface BulkInsertResponse {
    /** IDs of items inserted. */
    insertedItemIds?: string[];
    /** Error details for items that couldn't be inserted. */
    errors?: BulkError[];
}
interface BulkError {
    /** ID of the item that couldn't be inserted. */
    itemId?: string | null;
    /** Error message. */
    message?: string;
    /** Error details. */
    details?: Details;
    /** Index of the failed item in the `items` paramater of the request. */
    originalIndex?: number;
}
interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Error description. */
    description?: string;
    /** Error data. */
    data?: Record<string, any> | null;
}
interface Details {
    /** Application error. */
    applicationError?: ApplicationError;
}
interface BulkSaveRequest {
    /** Items to insert or update. */
    items: Record<string, any>[] | null;
    /** ID of the collection in which to insert or update the items. */
    dataCollectionId?: string;
}
interface BulkSaveResponse {
    /** IDs of items inserted. */
    insertedItemIds?: string[];
    /** IDs of items updated. */
    updatedItemIds?: string[];
    /** Errors for items that couldn't be inserted or updated. */
    errors?: BulkError[];
}
interface BulkUpdateRequest {
    /** Items to update. */
    items: Record<string, any>[] | null;
    /** ID of the collection in which to update items. */
    dataCollectionId?: string;
}
interface BulkUpdateResponse {
    /** IDs of items updated. */
    updatedItemIds?: string[];
    /** Errors for items that couldn't be updated. */
    errors?: BulkError[];
}
interface BulkRemoveRequest {
    /** IDs of items to remove. */
    entries?: BulkRemoveRequestEntry[];
    /** ID of the collection from which to remove the items. */
    dataCollectionId?: string;
}
interface BulkRemoveRequestEntry {
    /** ID of item to remove. */
    itemId?: string;
}
interface BulkRemoveResponse {
    /** IDs of items removed. */
    removedItemIds?: string[];
    /** Errors for items that couldn't be removed. */
    errors?: BulkError[];
}
interface QueryReferencedRequest {
    /** ID of the referring item. */
    referringItemId: string;
    /** Property containing the references to the referenced items. */
    propertyName: string;
    /** Paging preferences. */
    paging?: Paging;
    /** ID of the collection containing the referring item. */
    dataCollectionId?: string;
    /**
     * Whether to omit the total count in the response.
     * When `true`, the `pagingMetadata` object in the response doesn't contain a `total` field.
     *
     * Default: `false`
     */
    omitTotalCount?: boolean;
}
interface QueryReferencedResponse {
    /**
     * *Deprecated.** Refer to `entities` instead. List of referenced items.
     * @deprecated
     */
    items?: Record<string, any>[] | null;
    /**
     * *Deprecated**. Refer to 'pagingMetadata' instead. Total number of referenced items satisfying the query.
     * @deprecated
     */
    totalCount?: number;
    /**
     * *Deprecated**. Refer to 'pagingMetadata' instead. Total number of referenced items satisfying the query.
     * @deprecated
     */
    totalResults?: number;
    /** List of referenced items and/or IDs. For successfully resolved references, the referenced data item appears. For references that can't be resolved, the ID appears. */
    entities?: ReferencedEntity[];
    /** Paging information. */
    pagingMetadata?: PagingMetadataV2;
}
interface ReferencedEntity extends ReferencedEntityEntityOneOf {
    /** Data item referenced. */
    item?: Record<string, any> | null;
    /** Unresolved ID. Appears instead of the data item when the reference doesn't resolve. For example, when an ID isn't found or if an item is in draft state. */
    referenceId?: string;
}
/** @oneof */
interface ReferencedEntityEntityOneOf {
    /** Data item referenced. */
    item?: Record<string, any> | null;
    /** Unresolved ID. Appears instead of the data item when the reference doesn't resolve. For example, when an ID isn't found or if an item is in draft state. */
    referenceId?: string;
}
interface BulkInsertReferencesRequest {
    /**
     * References to insert.
     * @minSize 1
     */
    references: Reference[];
    /** ID of the collection containing the referring item. */
    dataCollectionId?: string;
}
interface Reference {
    /** Property containing the references to the referenced items. */
    propertyName?: string;
    /** ID of the referring item. */
    referringItemId?: string;
    /** ID of the referenced item. */
    referencedItemId?: string;
}
interface BulkInsertReferencesResponse {
}
interface BulkReplaceReferencesRequest {
    /** Property containing the references to the referenced items. */
    propertyName: string;
    /** ID of the referring item. */
    referringItemId: string;
    /** List of new referenced item IDs to replace the existing ones. */
    newReferencedItemIds?: string[];
    /** ID of the collection containing the referring item. */
    dataCollectionId?: string;
}
interface BulkReplaceReferencesResponse {
}
interface BulkRemoveReferencesRequest {
    /**
     * References to be removed.
     * @minSize 1
     */
    references: Reference[];
    /** ID of the collection containing the referring item. */
    dataCollectionId?: string;
}
interface BulkRemoveReferencesResponse {
}
interface IsReferencedRequest {
    /** Property that may contain a reference to the specified item. */
    propertyName: string;
    /** ID of the referring item. */
    referringItemId: string;
    /** ID of the item that may be referenced. */
    referencedItemId: string;
    /** ID of the collection containing the referring item. */
    dataCollectionId?: string;
}
interface IsReferencedResponse {
    /** Whether the specified property of the referring item contains a reference to the specified referenced item. */
    isReferenced?: boolean;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function insert(): __PublicMethodMetaInfo<'POST', {}, InsertRequest$1, InsertRequest, InsertResponse$1, InsertResponse>;
declare function update(): __PublicMethodMetaInfo<'PUT', {
    itemId: string;
}, UpdateRequest$1, UpdateRequest, UpdateResponse$1, UpdateResponse>;
declare function save(): __PublicMethodMetaInfo<'POST', {}, SaveRequest$1, SaveRequest, SaveResponse$1, SaveResponse>;
declare function get(): __PublicMethodMetaInfo<'GET', {
    itemId: string;
}, GetRequest$1, GetRequest, GetResponse$1, GetResponse>;
declare function remove(): __PublicMethodMetaInfo<'DELETE', {
    itemId: string;
}, RemoveRequest$1, RemoveRequest, RemoveResponse$1, RemoveResponse>;
declare function truncate(): __PublicMethodMetaInfo<'POST', {}, TruncateRequest$1, TruncateRequest, TruncateResponse$1, TruncateResponse>;
declare function query(): __PublicMethodMetaInfo<'GET', {}, QueryRequest$1, QueryRequest, QueryResponse$1, QueryResponse>;
declare function aggregate(): __PublicMethodMetaInfo<'POST', {}, AggregationRequest$1, AggregationRequest, AggregationResponse$1, AggregationResponse>;
declare function count(): __PublicMethodMetaInfo<'POST', {}, CountRequest$1, CountRequest, CountResponse$1, CountResponse>;
declare function distinct(): __PublicMethodMetaInfo<'POST', {}, DistinctRequest$1, DistinctRequest, DistinctResponse$1, DistinctResponse>;
declare function bulkInsert(): __PublicMethodMetaInfo<'POST', {}, BulkInsertRequest$1, BulkInsertRequest, BulkInsertResponse$1, BulkInsertResponse>;
declare function bulkSave(): __PublicMethodMetaInfo<'POST', {}, BulkSaveRequest$1, BulkSaveRequest, BulkSaveResponse$1, BulkSaveResponse>;
declare function bulkUpdate(): __PublicMethodMetaInfo<'POST', {}, BulkUpdateRequest$1, BulkUpdateRequest, BulkUpdateResponse$1, BulkUpdateResponse>;
declare function bulkRemove(): __PublicMethodMetaInfo<'POST', {}, BulkRemoveRequest$1, BulkRemoveRequest, BulkRemoveResponse$1, BulkRemoveResponse>;
declare function queryReferenced(): __PublicMethodMetaInfo<'POST', {}, QueryReferencedRequest$1, QueryReferencedRequest, QueryReferencedResponse$1, QueryReferencedResponse>;
declare function bulkInsertReferences(): __PublicMethodMetaInfo<'POST', {}, BulkInsertReferencesRequest$1, BulkInsertReferencesRequest, BulkInsertReferencesResponse$1, BulkInsertReferencesResponse>;
declare function bulkReplaceReferences(): __PublicMethodMetaInfo<'POST', {}, BulkReplaceReferencesRequest$1, BulkReplaceReferencesRequest, BulkReplaceReferencesResponse$1, BulkReplaceReferencesResponse>;
declare function bulkRemoveReferences(): __PublicMethodMetaInfo<'POST', {}, BulkRemoveReferencesRequest$1, BulkRemoveReferencesRequest, BulkRemoveReferencesResponse$1, BulkRemoveReferencesResponse>;
declare function isReferenced(): __PublicMethodMetaInfo<'POST', {}, IsReferencedRequest$1, IsReferencedRequest, IsReferencedResponse$1, IsReferencedResponse>;

export { type __PublicMethodMetaInfo, aggregate, bulkInsert, bulkInsertReferences, bulkRemove, bulkRemoveReferences, bulkReplaceReferences, bulkSave, bulkUpdate, count, distinct, get, insert, isReferenced, query, queryReferenced, remove, save, truncate, update };
